import { GraphQLUnionType, GraphQLTypeResolver } from "graphql";
import { TypeResolvable, ObjectType, Removable, KeyValue, ClassType } from "../../..";
import { GQLAnyType } from "../GQLAnyType";
export declare class UnionType<MetaType = KeyValue> extends GQLAnyType<GraphQLUnionType, MetaType> implements TypeResolvable {
    protected _types: (ObjectType | ClassType)[];
    protected _typeResolver: GraphQLTypeResolver<any, any>;
    get types(): (ClassType<any> | ObjectType<any, KeyValue>)[];
    get typeResolver(): GraphQLTypeResolver<any, any>;
    protected constructor(name: string, ...types: (ObjectType | ClassType)[]);
    static create(name: string, ...types: (ObjectType | ClassType)[]): UnionType<KeyValue>;
    /**
     * Set the union type resolver
     * @param typeResolver the type resolver function
     */
    setTypeResolver<TSource = any, TContext = any>(typeResolver: GraphQLTypeResolver<TSource, TContext>): this;
    /**
     * Set the types of the union
     * @param types The types of the union
     */
    setTypes(...types: (ObjectType | ClassType)[]): this;
    /**
     * Add some types to the union
     * @param types The types to add
     */
    addTypes(...types: (ObjectType | ClassType)[]): this;
    /**
     * Remove some types to the union
     * @param types The types to remove
     */
    removeTypes(...types: Removable<ObjectType | ClassType>): this;
    /**
     * Copy the UnionType
     */
    copy(): UnionType<KeyValue>;
    build(): GraphQLUnionType;
    defaultTypeResolver(obj: KeyValue): any;
}
